@@ -1,6 +1,7 @@
 from phue import Bridge
 import random
 import time
+import itertools
 
 def rgb_to_xy(red, green, blue):
     """ 
@@ -104,7 +105,7 @@ def change_color(room_name: str, color: str, IP_ADDRESS: str) -> bool:
             "red": [0.73, 0.24],
             "green": [0.11, 0.93],
             "blue": [0.16, 0.02],
-            "orange ": [0.57, 0.39],
+            "orange ": [0.56, 0.40],
             "yellow": [0.42, 0.61],
             "purple": [0.28, 0.09],
             "pink": [0.41, 0.22],
@@ -141,31 +142,29 @@ def loop_all_colors(room_name: str, IP_ADDRESS: str) -> bool:
     """
 
     try:
+        color_list = {
+            "red": [0.73, 0.24],
+            "green": [0.11, 0.93],
+            "blue": [0.16, 0.02],
+            "orange ": [0.56, 0.40],
+            "yellow": [0.42, 0.61],
+            "purple": [0.28, 0.09],
+            "pink": [0.41, 0.22],
+            "normal": [0.40, 0.55] 
+        }
 
-    	while True:
-	        color_list = {
-	            "red": [0.73, 0.24],
-	            "green": [0.11, 0.93],
-	            "blue": [0.16, 0.02],
-	            "orange ": [0.57, 0.39],
-	            "yellow": [0.42, 0.61],
-	            "purple": [0.28, 0.09],
-	            "pink": [0.41, 0.22],
-	            "normal": [0.40, 0.55] 
-	        }
+        b = Bridge(IP_ADDRESS)
 
-	        b = Bridge(IP_ADDRESS)
+        for color in itertools.cycle(list(color_list.keys())):
+            b.set_group(b.get_group_id_by_name(room_name), "on", True)
+            xy = color_list[color]
 
-	        for color in color_list:
-	            b.set_group(b.get_group_id_by_name(room_name), "on", True)
-	            xy = color_list[color]
+            lights = b.get_light_objects("name")
+            lights[room_name].brightness = 254
+            lights[room_name].xy = xy
+            time.sleep(1)
 
-	            lights = b.get_light_objects("name")
-	            lights[room_name].brightness = 254
-	            lights[room_name].xy = xy
-	            lights[room_name].transitiontime = 3
-
-	        return True
+        return True
 
     except:
         return False
